@@ -1,5 +1,3 @@
-
-
 #' Preference Selection
 #' 
 #' Evaluates a preference on a given data set, i.e., 
@@ -38,7 +36,7 @@
 #' The difference between the three variants of the preference selection is:
 #' 
 #' \itemize{
-#' \item The \code{psel} function returns a subset of the data set which are the maxima according to the given preference. 
+#' \item The \code{psel} function returns a subset of the data set which contains the maxima according to the given preference. 
 #' \item The function \code{psel.indices} returns just the row indices of the maxima 
 #' (except top-k queries with \code{show_level = TRUE}, see top-k preference selection).
 #' Hence \code{psel(df, pref)} is equivalent to \code{df[psel.indices(df, pref),]} for non-grouped data frames. 
@@ -55,7 +53,7 @@
 #' \itemize{
 #' \item{All the maxima of a data set w.r.t. a preference have level 1.}
 #' \item{The maxima of the remainder, i.e., the data set without the level 1 maxima, have level 2.}
-#' \item{The n-th iteration of "Take the maxima from the remainder" leads to tuples of level n.}
+#' \item{The n-th iteration of "Take the maxima from the remainder" returns tuples of level n.}
 #' }
 #' 
 #' By default, \code{psel.indices} does not return the level values. By setting \code{show_level = TRUE} this function
@@ -65,7 +63,7 @@
 #' 
 #' By definition, a top-k preference selection is non-deterministic. 
 #' A top-1 query of two equivalent tuples (equivalence according to \code{pref})
-#' can return on both of these tuples. 
+#' can return both of these tuples. 
 #' For example, a \code{top=1} preference selection on the tuples {(a=1, b=1), (a=1, b=2)}
 #' w.r.t. \code{low(a)} preference can return either the 'b=1' or the 'b=2' tuple. 
 #' 
@@ -117,25 +115,25 @@
 #' 
 #' @examples
 #' 
-#' # Skyline and top-k/at-least skyline
+#' # Skyline and top-k/at-least Skyline
 #' psel(mtcars, low(mpg) * low(hp))
 #' psel(mtcars, low(mpg) * low(hp), top = 5)
 #' psel(mtcars, low(mpg) * low(hp), at_least = 5)
 #' 
-#' # preference with associated data frame and evaluation
+#' # Preference with associated data frame and evaluation
 #' p <- low(mpg, df = mtcars) * (high(cyl) & high(gear))
 #' peval(p)
 #' 
-#' # visualize the skyline in a plot
+#' # Visualizes the Skyline in a plot.
 #' sky1 <- psel(mtcars, high(mpg) * high(hp))
 #' plot(mtcars$mpg, mtcars$hp)
 #' points(sky1$mpg, sky1$hp, lwd=3)
 #' 
-#' # grouped preference with dplyr
+#' # Grouped preference with dplyr.
 #' library(dplyr)
 #' psel(group_by(mtcars, cyl), low(mpg))
 #' 
-#' # return size of each maxima group
+#' # Returns the size of each maxima group.
 #' summarise(psel(group_by(mtcars, cyl), low(mpg)), n())
 #' 
 psel <- function(df, pref, ...) { 
@@ -224,7 +222,7 @@ psel.indices <- function(df, pref, ...) {
   # ** get grouping 
   
   raise_grouping_error <- function() {
-    stop("Could not find grouping indices in grouped data.frame! Probably rPref and dplyr became incompatible.")
+    stop("Could not find grouping indices in grouped data frame! Probably rPref and dplyr became incompatible.")
   }
   
   # (in dplyr 0.8 is.grouped_df is true for group_by(x) where x is a data.frame or data.table)
@@ -319,7 +317,7 @@ check.singleint.null2minus <- function(val, name) {
 
 df.pref.check <- function(df, pref) {
   # Note that also data.table fulfills is.data.frame(.) = TRUE
-  if (!is.data.frame(df))          stop.syscall("First argument has to be a data.frame.")
+  if (!is.data.frame(df))          stop.syscall("First argument has to be a data frame.")
   if (!is.actual.preference(pref)) stop.syscall("Second argument has to be a preference.")
 }
 
